#!/usr/bin/python3

#	alt-tasks-explorer : A set of utils used on top of the "alt-tasks" utility
#	Copyright (C) 2023 Alexey Appolonov
#
#	This program is free software: you can redistribute it and/or modify
#	it under the terms of the GNU General Public License as published by
#	the Free Software Foundation, either version 3 of the License, or
#	(at your option) any later version.
#
#	This program is distributed in the hope that it will be useful,
#	but WITHOUT ANY WARRANTY; without even the implied warranty of
#	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#	GNU General Public License for more details.
#
#	You should have received a copy of the GNU General Public License
#	along with this program.  If not, see <http://www.gnu.org/licenses/>.

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

import os
from datetime import datetime
from pathlib  import Path as path
from alt_tasks_explorer.status import Warn, FatalError

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

def __DateTimeNow():

	'''Get current time as a "YYYY-MM-DD_hh:mm:ss" string'''

	ts = datetime.now()

	return f'{ts.year}-{ts.month:02d}-{ts.day:02d}_' \
		f'{ts.hour:02d}-{ts.minute:02d}-{ts.second:02d}'

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

def WriteTmpFile(entries):

	'''Write a list of strings to a tmp file, with newlines'''

	file_path = ''
	home_dir  = os.path.join(path.home(), f'.alt-tasks')

	while True:
		file_name = f'{__DateTimeNow()}.tmp'
		file_path = os.path.join(home_dir, file_name)
		if not os.path.exists(file_path):
			break

	try:
		with open(file_path, "w") as f:
			for entry in entries:
				f.write(f'{entry}\n')
	except FileNotFoundError:
		FatalError(f'Home dir "{home_dir}" does not exist')
	except PermissionError:
		FatalError(f'No permission to write to the home dir "{home_dir}"')
	except Exceptopn as exc:
		FatalError(str(exc))

	return file_path

# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

def RemoveTmpFile(file_path):

	'''Remove specified file, display a warning msg if this cannot be done'''

	if not file_path:
		return

	try:
		os.remove(file_path)
	except FileNotFoundError:
		Warn(f'Temporary file "{file_path}" does not exist')
	except PermissionError:
		Warn(f'No permission to remove temporary file "{file_path}"')
	except Exceptopn as exc:
		Warn(str(exc))

	return
